
TODO_74_73_60_93: Support expected envelope count in config-only delegator

Add config for commands in `ConfigOnlyDelegator` to set expected number of `data_envelope`-s.

It is related to `FS_18_64_57_18.function_with_indefinite_input_data_envelopes_like_varargs.md`.

It should only apply to the last `envelope_container` because current behavior is to progress
to the next `envelope_container` only when the current one is singled out.
